
========
javalang
========

javalang is a pure Python library for working with Java source
code. javalang provies a lexer and parser targeting Java 7. The
implementation is based on the Java language spec available at
http://docs.oracle.com/javase/specs/jls/se7/html/.
